import { r as registerInstance, h } from './core-db63ec26.js';

const keys = ['inputs', 'outputs', 'props', 'events', 'methods'];
const Api = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    hasApi() {
        if (!this.doc) {
            return false;
        }
        for (const k of keys) {
            if (this.doc[k] && this.doc[k].length > 0) {
                return true;
            }
        }
    }
    angular() {
        return [
            this.doc.inputs ? this.doc.inputs.map(i => h("ad-input-def", { input: i })) : undefined,
            this.doc.outputs ? this.doc.outputs.map(i => h("ad-output-def", { output: i })) : undefined,
            this.doc.props ? this.doc.props.map(i => h("ad-prop-def", { prop: i })) : undefined
        ];
    }
    stencil() {
        return [
            this.doc.props ? this.doc.props.map(i => h("ad-prop-def", { prop: i })) : undefined,
            this.doc.events ? this.doc.events.map(i => h("ad-event-def", { event: i })) : undefined,
        ];
    }
    render() {
        if (!this.hasApi()) {
            return undefined;
        }
        const isAngular = !this.doc.tag;
        return (h("article", { id: "api", class: "api" }, h("h2", null, "API"), isAngular ? this.angular() : this.stencil(), this.doc.methods ? this.doc.methods.map(i => h("ad-method-def", { method: i })) : undefined));
    }
    static get style() { return ".sc-ad-api-h{display:block;font-size:.875rem;font-family:var(--anj-font-family);font-weight:400;line-height:1.5;outline:none}.sc-ad-api-h, .sc-ad-api-h:after, .sc-ad-api-h:before{-webkit-box-sizing:border-box;box-sizing:border-box;outline:none}.sc-ad-api-h:active, .sc-ad-api-h .sc-ad-api:active, .sc-ad-api-h:focus, .sc-ad-api-h .sc-ad-api:focus{outline:none}.sc-ad-api-h .api.sc-ad-api{border-bottom:1px solid var(--anj-border);margin-bottom:3rem;padding-bottom:3rem}.sc-ad-api-h .api.sc-ad-api h2.sc-ad-api{margin-bottom:1.5rem}"; }
};

const ApiName = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    static get style() { return "ad-api-name{display:inline;font-size:.875rem;font-family:var(--anj-font-family);font-weight:400;line-height:1.5;outline:none}ad-api-name,ad-api-name:after,ad-api-name:before{-webkit-box-sizing:border-box;box-sizing:border-box;outline:none}ad-api-name:active,ad-api-name :active,ad-api-name:focus,ad-api-name :focus{outline:none}ad-api-name:after{color:var(--anj-secondary-dark);content:\":\";margin-right:.5rem}"; }
};

const ArgDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return [
            h("ad-api-name", null, this.arg.name),
            h("ad-type-def", null, this.arg.type)
        ];
    }
    static get style() { return "ad-arg-def{display:inline;font-size:.875rem;font-family:var(--anj-font-family);font-weight:400;line-height:1.5;outline:none}ad-arg-def,ad-arg-def:after,ad-arg-def:before{-webkit-box-sizing:border-box;box-sizing:border-box;outline:none}ad-arg-def:active,ad-arg-def :active,ad-arg-def:focus,ad-arg-def :focus{outline:none}ad-arg-def:after{color:var(--anj-secondary-dark);content:\",\";margin-right:.5rem}ad-arg-def:last-child:after{content:none;margin-right:0}"; }
};

const Decorator = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    static get style() { return "ad-decorator{color:var(--anj-secondary-dark)}.api.ng ad-method-def ad-decorator,.api.ng ad-prop-def ad-decorator{display:none}"; }
};

const EventDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return [
            h("h4", null, h("ad-decorator", null, "@Event"), "\u00A0", h("ad-api-name", null, this.event.event), h("ad-type-def", null, "<", this.event.detail, ">")),
            h("p", null, this.event.docs)
        ];
    }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
};

const InputDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return [
            h("h4", null, h("ad-decorator", null, "@Input\u00A0"), h("ad-api-name", null, this.input.name), h("ad-type-def", null, this.input.type)),
            h("p", null, this.input.docs)
        ];
    }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
};

const MethodDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    nameless(name) {
        return `(${name.split('(')[1]}`;
    }
    render() {
        return [
            h("h4", null, h("ad-decorator", null, "@Method\u00A0"), h("ad-api-name", null, this.method.name), h("ad-type-def", null, this.nameless(this.method.signature))),
            h("p", null, this.method.docs)
        ];
    }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
};

const OutputDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return [
            h("h4", null, h("ad-decorator", null, "@Output\u00A0"), h("ad-api-name", null, this.output.name), h("ad-type-def", null, this.output.type)),
            h("p", null, this.output.docs)
        ];
    }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
};

const PropDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return [
            h("h4", null, h("ad-decorator", null, "@Prop\u00A0"), h("ad-api-name", null, this.prop.name), h("ad-type-def", null, this.prop.type)),
            h("p", null, this.prop.docs)
        ];
    }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
};

const RealTime = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    static get style() { return "ad-real-time{border:1px dashed var(--anj-border);border-radius:.25rem;display:block;margin-top:1.5rem;overflow-x:auto;padding:1rem;width:100%}"; }
};

const Toc = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.activeId = '#overview';
        /**
         * The object map of usa cases to their markdown
         */
        this.docs = {};
        /**
         * The object map of usa cases to their markdown
         */
        this.keys = [];
    }
    onDemosChange() {
        this.sectionIds = ['#overview'].concat(this.keys.map(d => `#${d}`)).concat('#api');
    }
    connectedCallback() {
        this.navigate = debounce(this.navigate.bind(this), 100);
        this.onScroll = debounce(this.onScroll.bind(this), 25);
        this.onDemosChange();
        if (window.location.hash) {
            this.navigate();
        }
    }
    onScroll() {
        const els = this.sectionIds.map(id => document.querySelector(id));
        let closest = els[0];
        els.slice(1).forEach(el => {
            if (el && Math.abs(window.scrollY - el.offsetTop) < Math.abs(window.scrollY - closest.offsetTop)) {
                closest = el;
            }
        });
        this.activeId = `#${closest.getAttribute('id')}`;
    }
    parseTitle(id) {
        const usage = id.replace('#', '');
        const doc = this.docs[usage];
        return doc ? doc.split(/##(.*?)\n/).find(p => p !== '').trim() : usage;
    }
    anchorClass(usage) {
        return usage === this.activeId ? 'anj-active' : '';
    }
    navigate() {
        return new Promise(resolve => {
            window.setTimeout(() => {
                this.activeId = window.location.hash;
                const el = document.querySelector(this.activeId);
                if (el) {
                    window.scrollTo(0, el.offsetTop);
                }
                resolve();
            }, 500);
        });
    }
    render() {
        if (!this.sectionIds) {
            return;
        }
        const path = window.location.pathname;
        return (h("div", { class: "anj-toc" }, this.sectionIds.map(id => h("a", { href: `${path}${id}`, onClick: () => this.activeId = id, class: this.anchorClass(id) }, this.parseTitle(id)))));
    }
    static get watchers() { return {
        "keys": ["onDemosChange"]
    }; }
    static get style() { return "ad-toc{display:block;position:relative}ad-toc .anj-toc{padding:1rem 0;position:fixed;top:3rem}ad-toc a{display:block;font-size:.75rem;margin-bottom:.5rem;text-transform:capitalize;-webkit-transition:color .2s ease;transition:color .2s ease}ad-toc a:focus{text-decoration:underline}ad-toc a:active{text-decoration:none}ad-toc a.anj-active,ad-toc a.anj-active:focus,ad-toc a.anj-active:hover{color:var(--anj-primary);text-decoration:none}"; }
};
const debounce = (func, wait = 0) => {
    let timer;
    return (...args) => {
        clearTimeout(timer);
        timer = setTimeout(func, wait, ...args);
    };
};

const TypeDef = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    static get style() { return "ad-type-def{color:var(--anj-neutral-dark);font-size:.75rem}"; }
};

export { Api as ad_api, ApiName as ad_api_name, ArgDef as ad_arg_def, Decorator as ad_decorator, EventDef as ad_event_def, InputDef as ad_input_def, MethodDef as ad_method_def, OutputDef as ad_output_def, PropDef as ad_prop_def, RealTime as ad_real_time, Toc as ad_toc, TypeDef as ad_type_def };
